;;; map.lisp --- Low-level map functions

;; ----------------------------------------------------------------------
;; -- Map and Tile Dimensions
;; ----------------------------------------------------------------------

;;;
;; Count the number of layers in the current map.
(defun map:count-layers ()
  "Get the number of layers for current map."
  (map:send-signal :COUNT-LAYERS))

;;;
;; Get the width and height of the current map.
(defun map:get-dimensions ()
  "Get the width and height of the current map in tiles."
  (map:send-signal :MAP-DIMENSIONS))

(defun map:get-width ()
  "Get the width of the current map in tiles."
  (car (map:get-dimensions)))

(defun map:get-height ()
  "Get the width of the current map in tiles."
  (cdr (map:get-dimensions)))

(defun map:get-tile-dimensions ()
  "Get the pixel width and height of tiles."
  (map:send-signal :TILE-DIMENSIONS))

(defun map:get-tile-width ()
  "Get the pixel width of tiles."
  (car (map:get-tile-dimensions)))

(defun map:get-tile-height ()
  "Get the pixel height of tiles."
  (cdr (map:get-tile-dimensions)))


;; ----------------------------------------------------------------------
;; -- Detailed info
;; ----------------------------------------------------------------------

(defun map:get-map-info ()
  "Get information about map."
  (map:send-signal :GET-MAP-INFO))

(defun map:get-tileset-info ()
  "Get information about map."
  (map:send-signal :GET-TILESET-INFO))


(defun map:get-tile-info (tile)
  "Get information about TILE."
  (map:send-signal :GET-TILE-INFO tile))


;; ----------------------------------------------------------------------
;; -- Manipulating Tiles
;; ----------------------------------------------------------------------

(defun map:get-tile (x y layer)
  "Get the tile at X and Y of LAYER."
  (map:send-signal :GET-TILE x y layer))

(defun map:set-tile (x y layer tile)
  "Set the tile at X and Y of LAYER to TILE."
  (map:send-signal :SET-TILE x y layer tile))

