;;; script-engine.lisp --- Helpers for working with the script engine

(defun process:exists? (pid)
  "Check if process PID exists."
  (not (nil? (process:send-signal pid :STATUS))))

(defun process:suspended? (pid)
  "Check if process PID is suspended."
  (eq? :SUSPENDED (process:send-signal pid :STATUS)))

(defun process:running? (pid)
  "Check if process PID is running."
  (eq? :RUNNING (process:send-signal pid :STATUS)))

(defun process:suspend (pid)
  "Stop process PID from running (but don't kill it)."
  (process:send-signal pid :SUSPEND))

(defun process:resume (pid)
  "Start PID process if paused."
  (process:send-signal pid :RESUME))

(defun process:kill (pid)
  "Kill process PID."
  (process:send-signal pid :KILL))

(defun process:sleep (pid time)
  "Tell process with PID to sleep for TIME milliseconds."
  (process:send-signal pid :SLEEP time))

;; Terminal the current process
(defmacro (break)
    `(process:send-signal ,%pid% :KILL))
